@@ -56,6 +56,11 @@ class PipedashWorker:
 
         return None
 
+    def get_rabbit_backend(self):
+        return "amqp://"+str(self._rabbit_user)+":"+str(self._rabbit_pwd)+"@"\
+               +str(self._rabbit_server)+":"+str(self._rabbit_port)+"/"
+
+
     def on_worker_command(self, commandMessage):
         identifier = commandMessage["component"]["component"]["identifier"]
         jobId = commandMessage["jobId"]
@@ -98,7 +103,7 @@ class PipedashWorker:
 
     async def run_worker_queue(self):
         connection = await aio_pika.connect_robust(
-            "amqp://thoren:thoren@78.47.96.243:5672/", loop=self.loop
+            self.get_rabbit_backend(), loop=self.loop
         )
 
         async with connection:
